@@ -2,12 +2,13 @@
 Library for consistent all-purpose 2D plots
 """
 
-#                          __
-#   ____  ____ ___  ____ _/ /
-#  / __ \/ __ `__ \/ __ `/ /
-# / /_/ / / / / / / /_/ /_/
-# \____/_/ /_/ /_/\__, (_)
-#                /____/
+#
+#   _|_|      _|_|_|  _|      _|    _|_|_|
+# _|    _|  _|        _|_|  _|_|  _|
+# _|    _|    _|_|    _|  _|  _|  _|  _|_|
+# _|    _|        _|  _|      _|  _|    _|
+#   _|_|    _|_|_|    _|      _|    _|_|_|
+#
 #
 # https://github.com/ioannis-vm/OpenSees_Model_Generator
 
@@ -35,50 +36,65 @@ C_BACKGROUND = "#FFE6A7"
 C_HOVERLABEL_BG = "#BB9457"
 
 
-def line_plot_interactive(title_text, x_vals, y_vals, mode,
-                          xlab="x", xunit=None, xhoverformat='.0f',
-                          ylab="y", yunit=None, yhoverformat='.0f'):
+def line_plot_interactive(
+    title_text,
+    x_vals,
+    y_vals,
+    mode,
+    xlab="x",
+    xunit=None,
+    xhoverformat=".0f",
+    ylab="y",
+    yunit=None,
+    yhoverformat=".0f",
+):
     """
     Gneric polty line plot
     """
     assert len(x_vals) == len(y_vals), "Dimensions don't match"
-    assert mode in ['spline+markers', 'line'], \
-        "mode can either be `spline+markers` or `line`"
+    assert mode in [
+        "spline+markers",
+        "line",
+    ], "mode can either be `spline+markers` or `line`"
 
-    if mode == 'line':
-        lshape = 'linear'
-        lmode = 'lines'
+    if mode == "line":
+        lshape = "linear"
+        lmode = "lines"
         lwidth = 2
-    elif mode == 'spline+markers':
-        lshape = 'spline'
-        lmode = 'lines+markers'
+    elif mode == "spline+markers":
+        lshape = "spline"
+        lmode = "lines+markers"
         lwidth = 4
     else:
         raise ValueError("oops! This should never run. Strange.")
 
     if xunit:
-        xtitle = f'{xlab} ({xunit})'
+        xtitle = f"{xlab} ({xunit})"
     else:
         xtitle = xlab
     if yunit:
-        ytitle = f'{ylab} ({yunit})'
+        ytitle = f"{ylab} ({yunit})"
     else:
         ytitle = ylab
 
     num_points = len(x_vals)
     indices: nparr = np.array([range(num_points)])
-    my_hovertemplate = \
-        'XY value pair: %{customdata[0]:d}<br>' + \
-        xlab + ' = %{x: ' + xhoverformat + '} '
+    my_hovertemplate = (
+        "XY value pair: %{customdata[0]:d}<br>"
+        + xlab
+        + " = %{x: "
+        + xhoverformat
+        + "} "
+    )
     if xunit:
-        my_hovertemplate += xunit + '<br>'
+        my_hovertemplate += xunit + "<br>"
     else:
-        my_hovertemplate += '<br>'
-    my_hovertemplate += ylab+' = %{y:' + yhoverformat + '} '
+        my_hovertemplate += "<br>"
+    my_hovertemplate += ylab + " = %{y:" + yhoverformat + "} "
     if yunit:
-        my_hovertemplate += yunit + '<extra></extra>'
+        my_hovertemplate += yunit + "<extra></extra>"
     else:
-        my_hovertemplate += '<extra></extra>'
+        my_hovertemplate += "<extra></extra>"
     fig = go.Figure(
         data=go.Scatter(
             x=x_vals,
@@ -86,13 +102,11 @@ def line_plot_interactive(title_text, x_vals, y_vals, mode,
             mode=lmode,
             line_shape=lshape,
             line=dict(color=C_LINE, width=lwidth),
-            marker=dict(color=C_BACKGROUND,
-                        size=10,
-                        line=dict(
-                            color=C_LINE,
-                            width=4)),
+            marker=dict(
+                color=C_BACKGROUND, size=10, line=dict(color=C_LINE, width=4)
+            ),
             customdata=np.reshape(indices, (-1, 1)),
-            hovertemplate=my_hovertemplate
+            hovertemplate=my_hovertemplate,
         )
     )
     fig.update_layout(
@@ -104,10 +118,10 @@ def line_plot_interactive(title_text, x_vals, y_vals, mode,
             linecolor=C_BACKGROUND,
             zerolinecolor=C_AXIS_LINE,
             linewidth=0,
-            ticks='outside',
+            ticks="outside",
             tickcolor=C_GRID,
             tickfont=dict(
-                family='Cambria',
+                family="Cambria",
                 size=14,
                 color=C_AXIS_LINE,
             ),
@@ -120,51 +134,44 @@ def line_plot_interactive(title_text, x_vals, y_vals, mode,
             linecolor=C_BACKGROUND,
             zerolinecolor=C_AXIS_LINE,
             linewidth=0,
-            ticks='outside',
+            ticks="outside",
             tickcolor=C_GRID,
             tickfont=dict(
-                family='Cambria',
+                family="Cambria",
                 size=14,
                 color=C_AXIS_LINE,
             ),
         ),
         showlegend=False,
-        plot_bgcolor=C_BACKGROUND
+        plot_bgcolor=C_BACKGROUND,
     )
     annotations = [
         dict(
-            xref='paper',
-            yref='paper',
+            xref="paper",
+            yref="paper",
             x=0.0,
             y=1.00,
-            xanchor='left', yanchor='bottom',
+            xanchor="left",
+            yanchor="bottom",
             text=title_text,
-            font=dict(family='Cambria',
-                      size=28,
-                      color=C_TITLE_COLOR),
-            showarrow=False
+            font=dict(family="Cambria", size=28, color=C_TITLE_COLOR),
+            showarrow=False,
         )
     ]
     fig.update_layout(annotations=annotations)
     fig.update_layout(
         xaxis_title=xtitle,
         yaxis_title=ytitle,
-        font=dict(
-            family='Cambria',
-            size=18,
-            color=C_LABEL_COLOR
-        ),
+        font=dict(family="Cambria", size=18, color=C_LABEL_COLOR),
         hoverlabel=dict(
-            bgcolor=C_HOVERLABEL_BG,
-            font_size=15,
-            font_family='Cambria'
-        )
+            bgcolor=C_HOVERLABEL_BG, font_size=15, font_family="Cambria"
+        ),
     )
     if "pytest" not in sys.modules:
         fig.show()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
 
 
