@@ -2,12 +2,13 @@
 Model Generator for OpenSees ~ line
 """
 
-#                          __
-#   ____  ____ ___  ____ _/ /
-#  / __ \/ __ `__ \/ __ `/ /
-# / /_/ / / / / / / /_/ /_/
-# \____/_/ /_/ /_/\__, (_)
-#                /____/
+#
+#   _|_|      _|_|_|  _|      _|    _|_|_|
+# _|    _|  _|        _|_|  _|_|  _|
+# _|    _|    _|_|    _|  _|  _|  _|  _|_|
+# _|    _|        _|  _|      _|  _|    _|
+#   _|_|    _|_|_|    _|      _|    _|_|_|
+#
 #
 # https://github.com/ioannis-vm/OpenSees_Model_Generator
 
@@ -15,7 +16,7 @@ from dataclasses import dataclass, field
 from typing import Optional
 import numpy as np
 import numpy.typing as npt
-from .import common
+from . import common
 
 # pylint: disable=no-else-return
 
@@ -32,45 +33,63 @@ class Line:
       start (numpy.ndarray): starting point
       end (numpy.ndarray): end point
     """
+
     tag: str
     start: nparr = field(repr=False)
     end: nparr = field(repr=False)
 
     def __repr__(self):
-        res = ''
-        res += 'Line object\n'
-        res += f'  start: {self.start}\n'
-        res += f'  end: {self.end}\n'
+        res = ""
+        res += "Line object\n"
+        res += f"  start: {self.start}\n"
+        res += f"  end: {self.end}\n"
         return res
 
     def length(self):
         """
-        returns the length of the line.
+        Returns the length of the line.
+
+        Example:
+            >>> from osmg.line import Line
+            >>> l1 = Line('l1', np.array([0, 0]), np.array([2, 2]))
+            >>> l1.length()
+            2.8284271247461903
         """
         return np.linalg.norm(self.end - self.start)
 
     def direction(self):
         """
-        returns a unit verctor pointing from the start to the end of
+        Returns a unit vector pointing from the start to the end of
         the line.
+
+        Example:
+            >>> from osmg.line import Line
+            >>> l1 = Line('l1', np.array([0, 0]), np.array([2, 2]))
+            >>> l1.direction()
+            array([0.70710678, 0.70710678])
         """
         return (self.end - self.start) / self.length()
 
-    def intersect(self, other: 'Line'):
+    def intersect(self, other: "Line") -> nparr:
         """
-        Calculates the intersection point of this line with another line.
-        Returns None if the lines don't intersect.
-        Note: 'line' is actually a finite-length line segment.
+        Calculates the intersection point of this line with another
+        line. Returns None if the lines don't intersect.  Note: 'line'
+        is actually a finite-length line segment.
+
         Parameters:
           other (Line): the other line
+
+        Example:
+            >>> from osmg.line import Line
+            >>> l1 = Line('l1', np.array([0, 0]), np.array([2, 2]))
+            >>> l2 = Line('l2', np.array([1, 0]), np.array([1, 3]))
+            >>> l1.intersect(l2)
+            array([1., 1.])
         """
         ra_dir = self.direction()
         rb_dir = other.direction()
         mat: nparr = np.array(
-            [
-                [ra_dir[0], -rb_dir[0]],
-                [ra_dir[1], -rb_dir[1]]
-            ]
+            [[ra_dir[0], -rb_dir[0]], [ra_dir[1], -rb_dir[1]]]
         )
         if np.abs(np.linalg.det(mat)) <= common.EPSILON:
             # The lines are parallel
@@ -84,7 +103,7 @@ class Line:
                 result = self.start
             elif np.linalg.norm(self.end - other.start) <= common.EPSILON:
                 result = self.end
-            elif np.linalg.norm(self.end - other.end) <= common. EPSILON:
+            elif np.linalg.norm(self.end - other.end) <= common.EPSILON:
                 result = self.end
             else:
                 result = None
@@ -118,18 +137,30 @@ class Line:
 
     def intersects_pt(self, point: nparr) -> bool:
         """
-        Check whether the given point pt
-        lies on the line
+        Check whether the given point pt lies on the line.
         Parameters:
-            pt (nparr): a point
+            point (nparr): a point
+        Returns:
+            bool: True if the point lies on the line, False otherwise
+        Examples:
+            >>> from osmg.line import Line
+            >>> l = Line('my_line', np.array([0, 0]), np.array([1, 1]))
+            >>> l.intersects_pt(np.array([0.5, 0.5]))
+            True
+            >>> l.intersects_pt(np.array([0, 0]))
+            True
+            >>> l.intersects_pt(np.array([1, 1]))
+            True
+            >>> l.intersects_pt(np.array([2, 2]))
+            False
         """
         r_a = self.end - self.start
         norm2 = np.dot(r_a, r_a)
         if np.abs(norm2) < 1.0e-4:
             raise ValueError
-        r_b = (point - self.start)
+        r_b = point - self.start
         cross = np.linalg.norm(np.cross(r_a, r_b))
-        dot_normalized = np.dot(r_a, r_b)/norm2  # type: ignore
+        dot_normalized = np.dot(r_a, r_b) / norm2  # type: ignore
         if cross < common.EPSILON:
             res = bool(0.00 <= dot_normalized <= 1.00)
         else:
@@ -138,11 +169,29 @@ class Line:
 
     def point_distance(self, point: nparr) -> Optional[float]:
         """
-        Calculates the projection of a point on the line.
-        If the projection falls on the line segment, it returns the
-        distance from the point to the line.
-        Arguments:
-          point (numpy.ndarray): the point's coordinates
+        Calculate the minimum distance between the line segment and a
+        point.  If the point falls on the line but is outside of the
+        line segment, returns None.
+        Parameters:
+            point (nparr): the point
+        Returns:
+            float: the minimum distance
+        Example:
+            >>> line = Line(tag='line',
+            ...             start=np.array([1, 1]),
+            ...             end=np.array([3, 3]))
+            >>> point = np.array([4, 2])
+            >>> line.point_distance(point)
+            1.4142135623730951
+            >>> point = np.array([2, 2])
+            >>> line.point_distance(point)
+            0.0
+            >>> point = np.array([0, 0])
+            >>> line.point_distance(point)
+
+            >>> point = np.array([4, 4])
+            >>> line.point_distance(point)
+
         """
         r_a = self.end - self.start
         r_b = point - self.start
@@ -157,9 +206,19 @@ class Line:
         """
         Calculates the projection of a point on the line.
         If the projection falls on the line segment, it returns the
-        projected point.
+        projected point, otherwise it returns None.
         Arguments:
           point (numpy.ndarray): the point's coordinates
+        Example:
+            >>> line = Line('test', np.array([0, 0]), np.array([10, 0]))
+            >>> line.project(np.array([5, 0]))
+            array([5., 0.])
+            >>> line.project(np.array([5, 5]))
+            array([5., 0.])
+            >>> line.project(np.array([-5, 5]))
+
+            >>> line.project(np.array([15, 5]))
+
         """
         r_a = self.end - self.start
         r_b = point - self.start
